#
# spec file for package maven-invoker
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           maven-invoker
Version:        3.3.0
Release:        2.1
Summary:        An API for firing a maven build in a clean environment
License:        Apache-2.0
Group:          Development/Libraries/Java
URL:            https://maven.apache.org/shared/maven-invoker/
Source0:        https://repo1.maven.org/maven2/org/apache/maven/shared/%{name}/%{version}/%{name}-%{version}-source-release.zip
Source1:        %{name}-build.xml
BuildRequires:  ant
BuildRequires:  atinject
BuildRequires:  fdupes
BuildRequires:  javapackages-local >= 6
BuildRequires:  maven-shared-utils >= 3.3.3
BuildRequires:  objectweb-asm
BuildRequires:  sisu-inject
BuildRequires:  unzip
BuildArch:      noarch

%description
This API is concerned with firing a Maven build in a new JVM. It accomplishes
its task by building up a conventional Maven command line from options given in
the current request, along with those global options specified in the invoker
itself. Once it has the command line, the invoker will execute it, and capture
the resulting exit code or any exception thrown to signal a failure to execute.
Input/output control can be specified using an InputStream and up to two
InvocationOutputHandlers.

This is a replacement package for maven-shared-invoker

%package javadoc
Summary:        Javadoc for %{name}
Group:          Documentation/HTML

%description javadoc
API documentation for %{name}.

%prep
%setup -q
cp %{SOURCE1} build.xml

%build
mkdir -p lib
build-jar-repository -s lib \
    atinject \
    maven-shared-utils \
    objectweb-asm/asm \
    org.eclipse.sisu.inject
%{ant} jar javadoc

%install
# jar
install -dm 0755 %{buildroot}%{_javadir}/%{name}
install -pm 0644 target/%{name}-%{version}.jar %{buildroot}%{_javadir}/%{name}/%{name}.jar
# pom
install -dm 0755 %{buildroot}%{_mavenpomdir}/%{name}
%{mvn_install_pom} pom.xml %{buildroot}%{_mavenpomdir}/%{name}/%{name}.pom
%add_maven_depmap %{name}/%{name}.pom %{name}/%{name}.jar
# javadoc
install -dm 0755 %{buildroot}%{_javadocdir}/%{name}
cp -pr target/site/apidocs/* %{buildroot}%{_javadocdir}/%{name}/
%fdupes -s %{buildroot}%{_javadocdir}

%files -f .mfiles
%license LICENSE NOTICE

%files javadoc
%license LICENSE NOTICE
%{_javadocdir}/%{name}

%changelog
* Tue Jun  3 2025 Fridrich Strba <fstrba@suse.com>
- Add dependency on objectweb-asm to build with sisu 0.9.0.M4
* Fri Sep 27 2024 Fridrich Strba <fstrba@suse.com>
- Upgrade to upstream version 3.3.0
  * New features and improvements
    + MSHARED-1040: Require Java 8
    + MSHARED-1019: Allow pass raw cli option to Maven process
    + MSHARED-1018: Allow for using the -ntp ,--no-transfer-progress
    flag in Maven invocations
    + MSHARED-1009: Allow providing Maven executable from workspace
    + MSHARED-649: Allow Pom file outside base directory
    + MSHARED-1007: Add MavenHome and MavenExecutable options to
    InvocationRequest
    + MINVOKER-233: Improve DefaultInvoker with a timeout.
    + MSHARED-1390: Deprecate InvocationRequest#setGoals
    + MSHARED-1382: support a possibility to disable snapshots
    update.
    + MSHARED-1150: Add ps1 as detectable file type for PowerShell
  * Bug Fixes
    + MSHARED-1008: Set builder id in proper way
    + MSHARED-971: Add test for inherited environment
  * Maintenance
    + MSHARED-577: Remove usage of M2_HOME environment variable
    + MSHARED-1006: Deprecate not thread safe methods on Invoker
    + Unit test MavenCommandLineBuilderTest refactor
    + remove --no-module-directories from javadoc configuration
    + remove unused property
    + remove deprecated class and use up to date JUnit fixtures
    + MSHARED-1152: Remove public modifier for JUnit5 tests
    + MSHARED-1391: Code cleanups
    + MSHARED-1389: Refresh download page
    + MSHARED-1307: systemProperties is deprecated:
    systemPropertyVariables instead
    + MSHARED-1306: Use fixtures to reduce duplicate code
    + MSHARED-1306: don't log from passing tests
    + MNG-6829: Replace any StringUtils#isEmpty(String) and
    [#]isNotEmpty(String)
    + MSHARED-1152: Migrate tests to JUnit5
    + MSHARED-1145: remove rendundant error message
- Removed patch:
  * maven-invoker-MSHARED-279.patch
    + rejected upstream
* Wed Feb 21 2024 Fridrich Strba <fstrba@suse.com>
- Use %%patch -P N instead of deprecated %%patchN.
* Mon Apr 25 2022 Fridrich Strba <fstrba@suse.com>
- Upgrade to upstream version 3.1.0
  * Improvement:
    + MSHARED-702 – Remove hard coded versions for
    plexus-component-annotations/plexus-component-metadata
  * Tasks:
    + MSHARED-625 – Refactored to use ‘maven-shared-utils’ instead
    of 'plexus-utils'.
    + MSHARED-729 – Upgrade to JDK 7 minimum.
  * Dependency upgrades:
    + MSHARED-700 – Upgrade parent to 31
    + MSHARED-728 – Upgrade maven-shared-utils to 3.2.1
  * Fixes build with maven-shared-utils 3.3.3
* Sun Mar 20 2022 Fridrich Strba <fstrba@suse.com>
- Build with java source and target levels 8
* Thu Nov 21 2019 Fridrich Strba <fstrba@suse.com>
- Upgrade to upstream version 3.0.1
  * needed by xmvn-tools >= 3.1.0
- Modified patch:
  * maven-invoker-MSHARED-279.patch
    + rediff to changed context
* Mon Apr  1 2019 Jan Engelhardt <jengelh@inai.de>
- Use noun phrase in summary.
* Thu Mar 14 2019 Fridrich Strba <fstrba@suse.com>
- Initial packaging of maven-invoker 2.2
- Generate and customize ant build.xml file
